<?php
/*
Plugin Name: Gallery Columns
Plugin URI: http://wordpress.org/extend/plugins/gallery-columns/
Description: By WordPress default, the number of gallery columns is 3. This plugin force and overwrite the current number of gallery columns within any post that uses <code>&#91;gallery&#93;</code> shortcode without altering or tampering its original options.
Version: 1.0.3
Author: Safirul Alredha
Author URI: http://zeo.my
License: GPLv2
*/

register_activation_hook( __FILE__, 'gallery_columns_install' );
	function gallery_columns_install() {
		$options = get_option( 'gallery_columns' );

		if ( ! is_array( $options ) ) {
			$defaults = array(
				'columns' => '3',
				'exclude' => '',
				'default_gallery_style' => 1,
			);

			foreach ( $defaults as $name => $value )
				if ( ! isset( $options[$name] ) )
					$options[$name] = $value;

			add_option( 'gallery_columns', $options );
		}
	}

add_filter( 'the_content', 'gallery_columns' );
	function gallery_columns( $content ) {
		global $post;

		$options = get_option( 'gallery_columns' );
		$columns = $options['columns'];
		$exclude = $options['exclude'];

		if ( $columns == '3' )
			return $content;

		if ( ! empty( $exclude ) ) {
			$exclude = is_array( $exclude ) ? $exclude : preg_split( '/[\s]*[,][\s]*/', $exclude );

			if ( in_array( $post->ID, $exclude ) )
				return $content;
		}

		$pattern = array(
			'#(\[gallery(.*?)columns="([0-9])"(.*?)\])#ie',
			'#(\[gallery\])#ie',
			'#(\[gallery(.*?)\])#ie'
		);
		$replace = 'stripslashes( strstr( "\1", "columns=\"$columns\"" ) ? "\1" : "[gallery \2 \4 columns=\"$columns\"]" )';

		return preg_replace( $pattern, $replace, $content );
	}

add_action( 'admin_menu', 'gallery_columns_admin_menu' );
	function gallery_columns_admin_menu() {
		$hook = add_options_page( 'Gallery Columns', 'Gallery Columns', 'manage_options', 'gallery-columns', 'gallery_columns_options_page' );
		add_action( 'load-' . $hook, 'gallery_columns_options_save' );
	}

	function gallery_columns_options_save() {
		if ( ! isset( $_POST['gallery-columns'] ) )
			return;

		check_admin_referer( 'gallery-columns-options' );

		$options = $newoptions = get_option( 'gallery_columns' );
		$newoptions['columns'] = (int) $_POST['columns'];
		$newoptions['exclude'] = strip_tags( stripslashes( $_POST['exclude'] ) );
		$newoptions['default_gallery_style'] = $_POST['default_gallery_style'];

		if ( $options != $newoptions ) {
			$options = $newoptions;
			update_option( 'gallery_columns', $options );
			wp_redirect( admin_url( 'options-general.php?page=gallery-columns&updated=true' ) );
			exit();
		}
	}

	function gallery_columns_options_page() {
		$options = get_option( 'gallery_columns' );
	?>
	<div class="wrap">
		<?php screen_icon(); ?>
		<h2>Gallery Columns Settings</h2>
			<form action="<?php echo admin_url( 'options-general.php?page=gallery-columns' ); ?>" method="post">
			<?php wp_nonce_field( 'gallery-columns-options' ); ?>
			<input type="hidden" name="gallery-columns" value="1" />
			<table class="form-table">
				<tr valign="top">
					<th scope="row"><label for="columns">Columns</label></th>
					<td>
					<select id="columns" name="columns">
						<?php for ( $i = 0; $i <= 10; ++$i ) echo "<option value='$i' " . ( $options['columns'] == $i ? "selected='selected'" : '' ) . ">$i</option>"; ?>
					</select>
					<span class="description">Specify the number of <code>&#91;gallery&#93;</code> columns. Default is set to 3.</span>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label for="exclude">Exclude</label></th>
					<td><input type="text" name="exclude" id="exclude" value="<?php echo $options['exclude']; ?>" class="regular-text" />
					<span class="description">Enter the Post IDs (separated by commas). Configuring this is optional. By default, it should be blank.</span>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label for="default_gallery_style">Gallery styles</label></th>
					<td><input type="checkbox" name="default_gallery_style" id="default_gallery_style" value="1" <?php checked( '1', $options['default_gallery_style'] ); ?> />
					Use WordPress default gallery inline styles.
					</td>
				</tr>
			</table>

			<?php submit_button(); ?>
			</form>
	</div><!-- END .wrap -->
	<?php }

add_action( 'init', 'gallery_columns_use_default_gallery_style' );
	function gallery_columns_use_default_gallery_style() {
		$options = get_option( 'gallery_columns' );
		if ( ! $options['default_gallery_style'] )
			add_filter( 'use_default_gallery_style', '__return_false' );
	}
